<?php
/**
 * Check and setup theme's default settings
 *
 * @package click5
 *
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! function_exists ( 'click5_setup_theme_default_settings' ) ) {
	function click5_setup_theme_default_settings() {

		$click5_posts_index_style = get_theme_mod( 'click5_posts_index_style' );
		if ( '' == $click5_posts_index_style ) {
			set_theme_mod( 'click5_posts_index_style', 'default' );
		}

		// Container width.
		$click5_container_type = get_theme_mod( 'click5_container_type' );
		if ( '' == $click5_container_type ) {
			set_theme_mod( 'click5_container_type', 'container' );
		}
	}
}

add_action('template_redirect', 'my_custom_disable_author_page');

function my_custom_disable_author_page() {
    global $wp_query;

    if ( is_author() ) { 
        wp_redirect(get_option('home'), 301); 
        exit; 
    }
}

function disable_emojis() {
	remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
	remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
	remove_action( 'wp_print_styles', 'print_emoji_styles' );
	remove_action( 'admin_print_styles', 'print_emoji_styles' ); 
	remove_filter( 'the_content_feed', 'wp_staticize_emoji' );
	remove_filter( 'comment_text_rss', 'wp_staticize_emoji' ); 
	remove_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );
	add_filter( 'tiny_mce_plugins', 'disable_emojis_tinymce' );
	add_filter( 'wp_resource_hints', 'disable_emojis_remove_dns_prefetch', 10, 2 );
}
add_action( 'init', 'disable_emojis' );
   

function disable_emojis_tinymce( $plugins ) {
	if ( is_array( $plugins ) ) {
		return array_diff( $plugins, array( 'wpemoji' ) );
	} else {
		return array();
	}
}

function disable_emojis_remove_dns_prefetch( $urls, $relation_type ) {
	if ( 'dns-prefetch' == $relation_type ) {
		$emoji_svg_url = apply_filters( 'emoji_svg_url', 'https://s.w.org/images/core/emoji/2/svg/' );

		$urls = array_diff( $urls, array( $emoji_svg_url ) );
	}

return $urls;
}

function is_blog () {
	global  $post;
			$postType = get_post_type($post);

	return ( ((is_archive()) || (is_author()) || (is_category()) || (is_home()) || (is_single()) || (is_tag())) && ( $postType == 'post')  ) ? true : false ;
}

function blog_menu_highlight($classes = array(), $menu_item = false) {
    if ( !is_404() && !is_page() && 12 == $menu_item->object_id && !in_array( 'active', $classes ) ) {
        $classes[] = 'active';        
    }

    return $classes;
}
add_filter('nav_menu_css_class', 'blog_menu_highlight', 100, 2); 
   
add_filter('show_admin_bar', '__return_false');

function check_background() {
	if ( has_post_thumbnail() ){
			$featured_img_url = get_the_post_thumbnail_url(get_the_ID()); 
	} else {
			$featured_img_url = bloginfo('template_url') . '/img/hero.jpg';
	}

	return $featured_img_url;
}

function get_primary_category( $post = 0, $taxonomy = 'category' ) {	
    if ( !$post ) {
		$post = get_the_ID();
	}

	$terms = get_the_terms( $post, $taxonomy );

	if ($terms) {
		if ( class_exists('WPSEO_Primary_Term') ) {
            $wpseo_primary_term = new WPSEO_Primary_Term( $taxonomy, $post );
            $wpseo_primary_term = $wpseo_primary_term->get_primary_term();
            $term = get_term( $wpseo_primary_term );
    
            if ( is_wp_error( $term ) ) {
                $primary_category = $terms[0]->term_id;
            } else {
                $primary_category = $term->term_id; 
            }        
        } else {
            $primary_category = $terms[0]->term_id;
        }
	} else {
		$primary_category = 0;
	}
    
	return $primary_category;
}

function get_reading_time($text) {
    $totalReadTm = ceil(str_word_count($text) / 200);

    if ($totalReadTm == 1) {
        $totalReadTm = $totalReadTm . ' minute read';
    } else {
        $totalReadTm = $totalReadTm . ' minutes read';
    }

    return $totalReadTm;
}

add_shortcode('bloginfo', function($atts) {
	$atts = shortcode_atts(array('filter' => '', 'info' => ''), $atts, 'bloginfo');
 
	$infos = array(
	  'name', 'description',
	  'wpurl', 'url', 'pingback_url',
	  'admin_email', 'charset', 'version', 'html_type', 'language',
	  'atom_url', 'rdf_url','rss_url', 'rss2_url',
	  'comments_atom_url', 'comments_rss2_url', 'email_domain'
	);

	if($atts['info'] == 'email_domain') {
		$remove = array("http://","https://", "www");
		$val = str_replace($remove, "", get_bloginfo('url'));
	} elseif(in_array($atts['info'], $infos, true)) {
		$val = get_bloginfo($atts['info'], $filter);
	} else {
		$val = '';
	}
 
	return $val;
});

add_filter('wpcf7_form_elements', function ($content) {
    $content = preg_replace(
				'/<label><input type="(checkbox|radio)" name="(.*?)" value="(.*?)" \/><span class="wpcf7-list-item-label">/i', 
				'<label class="custom-control custom-\1"><input type="\1" name="\2" value="\3" class="custom-control-input"><span class="wpcf7-list-item-label custom-control-label">', 
				$content
			);

    return $content;
});

add_shortcode('bloginfo', function($atts) {
	extract(shortcode_atts(array(
		'key' => '',
	), $atts));

	if($key == 'domain') {
		$bloginfo = str_replace(array("http://","https://", "www."), "", get_bloginfo('url'));
	} else {
		$bloginfo = get_bloginfo($key);
	}
 
	return $bloginfo;
});

add_shortcode('video', function($atts) {
	extract(shortcode_atts(array(
		'id' => '',
		'poster' => ''
	), $atts));

	if(!$poster) {
		$poster = 'http://img.youtube.com/vi/'. $id .'/maxresdefault.jpg';
	}

	$video = '<div class="js-video-button video" data-video-id="'. $id .'" style="background-image: url(\''. $poster .'\');"></div>';
 
	return $video;
});