<?php
/**
 * Template Name: Home
 *
 * @package click5
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

get_header();
$container = get_theme_mod( 'click5_container_type' );
?>

<?php if(have_rows("hero_slides")) : $slides = count(get_field("hero_slides")); ?>

<div class="wrapper mb-4" id="hero">
	<div id="myCarousel" class="carousel slide" data-ride="carousel">
		<ol class="carousel-indicators">
			<?php for($i = 0; $i < $slides; $i++) : ?>
			<li data-target="#myCarousel" data-slide-to="<?php echo $i; ?>"<?php echo ($i == 0) ? ' class="active"' : ''; ?>></li>
			<?php endfor; ?>
		</ol>

		<div class="carousel-inner">
			
			<?php $s = 1; while(have_rows("hero_slides")) : the_row(); ?>

			<div class="carousel-item<?php echo ($s == 1) ? ' active' : ''; ?>">
				<img class="d-block w-100" src="<?php echo get_sub_field("image"); ?>" />
				<div class="<?php echo esc_attr( $container ); ?>">
					<div class="carousel-caption text-center py-5">
						<h1><?php echo get_sub_field("headline"); ?></h1>
						<p><?php echo get_sub_field("text"); ?></p>
						<p><a class="btn btn-lg btn-light" href="<?php echo get_sub_field("button_url"); ?>" role="button"><?php echo get_sub_field("button"); ?></a></p>
					</div>
				</div>
			</div>

			<?php $s++; endwhile; ?>
		</div>

		<a class="carousel-control-prev" href="#myCarousel" role="button" data-slide="prev">
			<span class="carousel-control-prev-icon" aria-hidden="true"></span>
			<span class="sr-only">Previous</span>
		</a>

		<a class="carousel-control-next" href="#myCarousel" role="button" data-slide="next">
			<span class="carousel-control-next-icon" aria-hidden="true"></span>
			<span class="sr-only">Next</span>
		</a>
	</div>
</div>

<?php endif; ?>

<?php if(have_rows("services_items")) : ?>

<div class="wrapper pb-3" id="about">
	<div class="<?php echo esc_attr( $container ); ?>">
		<div class="row">
			<?php while(have_rows("services_items")) : the_row(); ?>

			<div class="col-lg-4 text-center">
				<img class="rounded-circle" src="<?php echo get_sub_field("photo"); ?>" width="140" height="140">
				<h2><?php echo get_sub_field("title"); ?></h2>
				<p><?php echo get_sub_field("text"); ?></p>
				<p><a class="btn btn-secondary" href="<?php echo get_sub_field("button_url"); ?>" role="button"><?php echo get_sub_field("button"); ?> &raquo;</a></p>
			</div>
			
			<?php endwhile; ?>
		</div>
	</div>
</div>

<?php endif; ?>

<?php if(get_field("video_file") || get_field("video_url") != '') : ?>

<div class="wrapper" id="video">
	<div class="<?php echo esc_attr( $container ); ?>">
		<div class="row">
			<div class="col-lg-10 offset-lg-1">
				<?php
					$video_id = parse_url(get_field("video_url"));
					parse_str($video_id['query'], $query);
				?>

				<div class="js-video-button video" data-url="<?php echo get_field("video_url"); ?>" <?php echo (get_field("video_file")) ? 'data-video-url="'.get_field("video_file").'"' : 'data-video-id="'.$query['v'].'"'; ?>>
					<picture class="icon">
						<source srcset="<?php echo get_field("video_poster"); ?>" type="image/webp">
						<source srcset="<?php echo str_replace(".webp", ".jpg", get_field("video_poster")); ?>" type="image/jpeg"> 
						<img src="<?php echo get_field("video_poster"); ?>" alt="video">
					</picture>
				</div>
			</div>
		</div>
	</div>
</div>

<?php endif; ?>

<?php if(have_rows("boxes_items")) : $boxes = count(get_field("boxes_items")); ?>

<div class="wrapper pt-5" id="services">
	<div class="<?php echo esc_attr( $container ); ?>">
		<?php $b = 1; while(have_rows("boxes_items")) : the_row(); ?>

		<div class="row">
			<div class="col-md-7 d-flex flex-column justify-content-center<?php echo ($b % 2 == 0) ? ' order-md-2' : ''; ?>">
				<h2 class="heading"><?php echo get_sub_field("title"); ?></h2>
				<?php echo get_sub_field("text"); ?>
			</div>

			<div class="col-md-5<?php echo ($b % 2 == 0) ? ' order-md-1' : ''; ?>">
				<img class="img-fluid mx-auto" src="<?php echo get_sub_field("photo"); ?>" />
			</div>
		</div>

		<?php if($b < $boxes) : ?><hr class="divider"><?php endif; ?>

		<?php $b++; endwhile; ?>		
	</div>
</div>

<?php endif; ?>

<?php if(have_rows("testimonials_items")) : $testimonials = count(get_field("testimonials_items")); ?>

<div class="wrapper" id="testimonials-wrapper">
	<div class="<?php echo esc_attr( $container ); ?>">
		<div class="row">
			<div class="col-lg-10 col-center m-auto">
				<div id="testimonials" class="carousel slide" data-ride="carousel">  
					<div class="carousel-inner">
						<?php $t = 1; while(have_rows("testimonials_items")) : the_row(); ?>

						<div class="item carousel-item<?php echo ($t == 1) ? ' active' : ''; ?>">
							<div class="img-box">
								<img src="<?php echo get_sub_field("photo"); ?>" alt="photo" />
							</div>

							<p class="testimonial"><?php echo get_sub_field("text"); ?></p>
							<p class="overview"><?php echo get_sub_field("name"); ?></p>
						</div>

						<?php $t++; endwhile; ?>
					</div>

					<ol class="carousel-indicators circle">
						<?php for($i = 0; $i < $testimonials; $i++) : ?>
						<li data-target="#testimonials" data-slide-to="<?php echo $i; ?>"<?php echo ($i == 0) ? ' class="active"' : ''; ?>></li>
						<?php endfor; ?>
					</ol> 
					
					<a class="carousel-control left carousel-control-prev" href="#testimonials" data-slide="prev">
						<i class="fa fa-angle-left"></i>
					</a>

					<a class="carousel-control right carousel-control-next" href="#testimonials" data-slide="next">
						<i class="fa fa-angle-right"></i>
					</a>
				</div>
			</div>
		</div>
	</div>
</div>

<?php endif; ?>

<?php get_footer(); ?>